@@ -8,12 +8,12 @@ field name => {
     min_alpha => 4,
 };
 
-field x_axis => {
+field x => {
     filters => ['trim', 'strip', 'numeric'],
     default => 0
 };
 
-field y_axis => {
+field y => {
     filters => ['trim', 'strip', 'numeric'],
     default => 0
 };
@@ -26,14 +26,14 @@ command new => sub {
 
 command move => sub {
     my ($self, $opts, $args) = @_;
-    $self->validate('name', 'y_axis', 'x_axis') or $self->render_errors;
+    $self->validate('name', 'y', 'x') or $self->render_errors;
     # move ship to different coordinates
     # e.g. using $opts->{speed} which defaults to 10
 };
 
 command shoot => sub {
     my ($self, $opts, $args) = @_;
-    $self->validate('name', 'x_axis', 'y_axis') or $self->render_errors;
+    $self->validate('name', 'x', 'y') or $self->render_errors;
     # fire projectiles from ship
 };
 
@@ -50,8 +50,8 @@ Battleship Script.
 
 Usage:
     yourcmd new <name>
-    yourcmd move <name> <x_axis> <y_axis> [--speed=<kn>]
-    yourcmd shoot <name> <x_axis> <y_axis>
+    yourcmd move <name> <x> <y> [--speed=<kn>]
+    yourcmd shoot <name> <x> <y>
 
 Options:
     --speed=<kn>  Speed in knots [default: 10].
